jgtfx2console
====

Enhanced PDS Services ALT console


Installation
------------

::

    pip install --user -U jgtfx2console

Example
-------

::


    >>> fx2console -i SPX500 -t H4 > SPX500_H4.csv
   
